@@ -164,6 +164,7 @@ public:
         // QFontDatabase::systemFont(QFontDatabase::FixedFont);
 
         mEdit->setFont(fixedFont);
+        mEdit->setAcceptRichText(false);
         mEdit->setMinimumWidth(QFontMetrics(fixedFont).averageCharWidth() * 70);
 
         if (KeyCache::instance()->pgpOnly()) {
@@ -399,7 +400,7 @@ public:
 
         const auto sigKey = mSigEncWidget->signKey();
 
-        bool encrypt = mSigEncWidget->encryptSymmetric() || mSigEncWidget->recipients().size();
+        bool encrypt = mSigEncWidget->encryptSymmetric() || !mSigEncWidget->recipients().isEmpty();
         bool sign = !sigKey.isNull();
 
         if (sign) {
@@ -502,7 +503,7 @@ public:
     }
 
 private:
-    PadWidget *q;
+    PadWidget *const q;
     QTextEdit *mEdit;
     QPushButton *mCryptBtn;
     QPushButton *mDecryptBtn;
